@@ -126,6 +126,7 @@ int Usage(char *argv) {
            "  -C, --enable-capture-sources Comma separated list of named packet sources to use.\n"
            "  -p, --port <port>            TCPIP server port for stream connections\n"
            "  -a, --allowed-hosts <hosts>  Comma separated list of hosts allowed to connect\n"
+           "  -b, --bind-address <address>    Bind to this address. Default INADDR_ANY.\n"
            "  -s, --silent                 Don't send any output to console.\n"
            "  -N, --server-name            Server name\n"
            "  -v, --version                Kismet version\n"
@@ -146,7 +147,7 @@ int main(int argc, char *argv[]) {
 
     char status[STATUS_MAX];
     
-    string allowed_hosts;
+    string allowed_hosts, bind_addr;
     int tcpport = -1;
     int tcpmax;
 
@@ -185,6 +186,7 @@ int main(int argc, char *argv[]) {
         { "enable-capture-sources", required_argument, 0, 'C' },
         { "port", required_argument, 0, 'p' },
         { "allowed-hosts", required_argument, 0, 'a' },
+        { "bind-address", required_argument, 0, 'b'},
         { "server-name", required_argument, 0, 'N' },
         { "help", no_argument, 0, 'h' },
         { "version", no_argument, 0, 'v' },
@@ -204,7 +206,7 @@ int main(int argc, char *argv[]) {
     signal(SIGPIPE, SIG_IGN);
 
     while(1) {
-        int r = getopt_long(argc, argv, "f:c:C:p:a:N:hvsI:xXM:",
+        int r = getopt_long(argc, argv, "f:c:C:p:a:b:N:hvsI:xXM:",
                             long_options, &option_index);
         if (r < 0) break;
         switch(r) {
@@ -231,7 +233,7 @@ int main(int argc, char *argv[]) {
             break;
         case 'C':
             // Named sources
-            named_sources = optarg;
+            named_sources = string(optarg);
             fprintf(stderr, "Using specified capture sources: %s\n", named_sources.c_str());
             break;
         case 'p':
@@ -243,7 +245,10 @@ int main(int argc, char *argv[]) {
             break;
         case 'a':
             // Allowed
-            allowed_hosts = optarg;
+            allowed_hosts = string(optarg);
+            break;
+        case 'b':
+            bind_addr = string(optarg);
             break;
         case 'N':
             // Servername
@@ -355,7 +360,7 @@ int main(int argc, char *argv[]) {
 
 #ifdef HAVE_GPS
     if (conf->FetchOpt("gps") == "true") {
-        if (sscanf(conf->FetchOpt("gpshost").c_str(), "%1024[^:]:%d", gpshost, &gpsport) != 2) {
+        if (sscanf(conf->FetchOpt("gpshost").c_str(), "%1023[^:]:%d", gpshost, &gpsport) != 2) {
             fprintf(stderr, "Invalid GPS host in config (host:port required)\n");
             exit(1);
         }
@@ -570,9 +575,19 @@ int main(int argc, char *argv[]) {
         allowed_hosts = conf->FetchOpt("allowedhosts");
     }
 
+    if (bind_addr.length() == 0) {
+        if (conf->FetchOpt("bindaddress") == "") {
+            fprintf(stderr, "NOTICE: bind address not specified, using INADDR_ANY.\n");
+        }
+
+        bind_addr = conf->FetchOpt("bindaddress");
+    }
+        
+    
+
     // Parse the allowed hosts into the vector
-    unsigned int ahstart = 0;
-    unsigned int ahend = allowed_hosts.find(",");
+    size_t ahstart = 0;
+    size_t ahend = allowed_hosts.find(",");
 
     int ahdone = 0;
     while (ahdone == 0) {
@@ -590,7 +605,7 @@ int main(int argc, char *argv[]) {
         client_ipblock *ipb = new client_ipblock;
 
         // Find the netmask divider, if one exists
-        unsigned int masksplit = hoststr.find("/");
+        size_t masksplit = hoststr.find("/");
         if (masksplit == string::npos) {
             // Handle hosts with no netmask - they're treated as single hosts
             inet_aton("255.255.255.255", &(ipb->mask));
@@ -672,7 +687,7 @@ int main(int argc, char *argv[]) {
         free(maskaddr);
     }
 
-    if (streamer.Setup(tcpmax, tcpport, &legal_ipblock_vec) < 0) {
+    if (streamer.Setup(tcpmax, bind_addr, tcpport, &legal_ipblock_vec) < 0) {
         fprintf(stderr, "Failed to set up stream server: %s\n", streamer.FetchError());
         CatchShutdown(-1);
     }
